@@ -298,6 +298,7 @@ webkit_pref_callback_accept_languages (GSettings *settings,
 
   g_strfreev (languages);
   g_free (langs_str);
+  g_array_free (array, TRUE);
 }
 
 void
@@ -329,10 +330,8 @@ webkit_pref_callback_cookie_accept_policy (GSettings *settings,
                                            gpointer data)
 {
   SoupSession *session;
-  char *webkit_pref;
   char *value = NULL;
 
-  webkit_pref = data;
   value = g_settings_get_string (settings, key);
 
   if (value) {
@@ -340,8 +339,10 @@ webkit_pref_callback_cookie_accept_policy (GSettings *settings,
 
     session = webkit_get_default_session ();
     jar = soup_session_get_feature (session, SOUP_TYPE_COOKIE_JAR);
-    if (!jar)
+    if (!jar) {
+      g_free (value);
       return;
+    }
     
     ephy_embed_prefs_set_cookie_jar_policy (SOUP_COOKIE_JAR (jar), value);
   }
@@ -357,13 +358,19 @@ webkit_pref_callback_gnome_fonts (GSettings *ephy_settings,
   GSettings *settings;
 
   if (g_settings_get_boolean (ephy_settings, key)) {
-    g_object_set (webkit_settings,
-                  "default-font-family", "serif",
-                  "sans-serif-font-family", "sans-serif",
-                  "monospace-font-family", "monospace",
-                  "default-font-size", 12,
-                  "default-monospace-font-size", 10,
-                  NULL);
+    settings = ephy_settings_get ("org.gnome.desktop.interface");
+
+    webkit_pref_callback_font_size (settings, "document-font-name",
+                                    "default-font-size");
+    webkit_pref_callback_font_size (settings, "monospace-font-name",
+                                    "default-monospace-font-size");
+
+    webkit_pref_callback_font_family (settings, "document-font-name",
+                                      "default-font-family");
+    webkit_pref_callback_font_family (settings, "font-name",
+                                      "sans-serif-font-family");
+    webkit_pref_callback_font_family (settings, "monospace-font-name",
+                                      "monospace-font-family");
   } else {
     /* Sync with Epiphany values */
     settings = ephy_settings;
@@ -377,15 +384,60 @@ webkit_pref_callback_gnome_fonts (GSettings *ephy_settings,
                                       "default-font-family");
     webkit_pref_callback_font_family (settings, EPHY_PREFS_WEB_SANS_SERIF_FONT,
                                       "sans-serif-font-family");
+
     webkit_pref_callback_font_family (settings, EPHY_PREFS_WEB_MONOSPACE_FONT,
                                       "monospace-font-family");
+
     webkit_pref_callback_font_family (settings, EPHY_PREFS_WEB_SERIF_FONT,
                                       "serif-font-family");
   }
 }
 
+static void
+webkit_pref_callback_enable_spell_checking (GSettings *settings,
+                                            char *key,
+                                            gpointer data)
+{
+  gboolean value = FALSE;
+  char **languages;
+  char *langs = NULL;
+
+  value = g_settings_get_boolean (settings, key);
+
+  if (value) {
+    languages = g_settings_get_strv (settings, EPHY_PREFS_WEB_LANGUAGE);
+    langs = g_strjoinv (",", languages);
+    g_strdelimit (langs, "-", '_');
+  }
+
+  g_object_set (webkit_settings, "enable-spell-checking", value, NULL);
+  g_object_set (webkit_settings, "spell-checking-languages", langs, NULL);
+}
+
 static const PrefData webkit_pref_entries[] =
   {
+    /* GNOME font settings */
+    { "org.gnome.desktop.interface",
+      "document-font-name",
+      "default-font-size",
+      webkit_pref_callback_font_size },
+    { "org.gnome.desktop.interface",
+      "monospace-font-name",
+      "default-monospace-font-size",
+      webkit_pref_callback_font_size },
+    { "org.gnome.desktop.interface",
+      "document-font-name",
+      "default-font-family",
+      webkit_pref_callback_font_family },
+    { "org.gnome.desktop.interface",
+      "font-name",
+      "sans-serif-font-family",
+      webkit_pref_callback_font_family },
+    { "org.gnome.desktop.interface",
+      "monospace-font-name",
+      "monospace-font-family",
+      webkit_pref_callback_font_family },
+
     /* Epiphany font settings */
     { EPHY_PREFS_WEB_SCHEMA,
       EPHY_PREFS_WEB_SERIF_FONT,
@@ -417,6 +469,11 @@ static const PrefData webkit_pref_entries[] =
       NULL,
       webkit_pref_callback_gnome_fonts },
 
+    { EPHY_PREFS_WEB_SCHEMA,
+      EPHY_PREFS_WEB_ENABLE_SPELL_CHECKING,
+      NULL,
+      webkit_pref_callback_enable_spell_checking },
+
     { EPHY_PREFS_WEB_SCHEMA,
       EPHY_PREFS_WEB_ENABLE_USER_CSS,
       "user-stylesheet-uri",
