@@ -36,6 +36,7 @@
 #include "ephy-profile-utils.h"
 #include "ephy-prefs.h"
 #include "ephy-settings.h"
+#include "ephy-request-about.h"
 
 #ifdef ENABLE_CERTIFICATE_MANAGER
 #include "ephy-certificate-manager.h"
@@ -45,6 +46,7 @@
 #include <glib/gi18n.h>
 #include <libsoup/soup-gnome.h>
 #include <libsoup/soup-cache.h>
+#include <libsoup/soup-requester.h>
 #include <gnome-keyring.h>
 
 #define EPHY_EMBED_SINGLE_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_EMBED_SINGLE, EphyEmbedSinglePrivate))
@@ -483,9 +485,8 @@ ephy_embed_single_initialize (EphyEmbedSingle *single)
   char *filename;
   char *cookie_policy;
   char *cache_dir;
-  WebKitWebPluginDatabase* database;
-  GSList *list, *p;
   EphyEmbedSinglePrivate *priv = single->priv;
+  SoupSessionFeature *requester;
 
   /* Initialise nspluginwrapper's plugins if available */
   if (g_file_test (NSPLUGINWRAPPER_SETUP, G_FILE_TEST_EXISTS) != FALSE)
@@ -539,6 +540,12 @@ ephy_embed_single_initialize (EphyEmbedSingle *single)
                     G_CALLBACK (cache_size_cb),
                     single);
 
+  /* about: URIs handler */
+  requester = SOUP_SESSION_FEATURE (soup_requester_new());
+  soup_session_add_feature (session, requester);
+  soup_session_feature_add_feature (requester, EPHY_TYPE_REQUEST_ABOUT);
+  g_object_unref (requester);
+
 #ifdef SOUP_TYPE_PASSWORD_MANAGER
   /* Use GNOME keyring to store passwords. Only add the manager if we
      are not using a private session, otherwise we want any new
@@ -548,18 +555,6 @@ ephy_embed_single_initialize (EphyEmbedSingle *single)
     soup_session_add_feature_by_type (session, SOUP_TYPE_PASSWORD_MANAGER_GNOME);
 #endif
 
-  /* Disable Flash by default, since it uses GTK+2.x and we can't mix
-   * it in our GTK+3.x process */
-  database = webkit_get_web_plugin_database ();
-  list = webkit_web_plugin_database_get_plugins (database);
-  for (p = list; p; p = p->next) {
-    WebKitWebPlugin *plugin = WEBKIT_WEB_PLUGIN (p->data);
-    if (g_strcmp0 (webkit_web_plugin_get_name (plugin), "Shockwave Flash") == 0)
-      webkit_web_plugin_set_enabled (plugin, FALSE);
-  }
-
-  webkit_web_plugin_database_plugins_list_free (list);
-
   return TRUE;
 }
 
@@ -607,6 +602,8 @@ ephy_embed_single_set_network_status (EphyEmbedSingle *single,
 {
   if (status != single->priv->online)
     single->priv->online = status;
+
+  g_object_notify (G_OBJECT (single), "network-status");
 }
 
 /**
