@@ -52,7 +52,6 @@ gboolean           ephy_file_helpers_init        (const char  *profile_dir,
 const char *       ephy_file                     (const char  *filename);
 const char *       ephy_dot_dir                  (void);
 void               ephy_file_helpers_shutdown    (void);
-char       *       ephy_file_downloads_dir       (void);
 char	   *       ephy_file_get_downloads_dir   (void);
 char       *       ephy_file_desktop_dir         (void);
 const char *       ephy_file_tmp_dir             (void);
@@ -85,6 +84,8 @@ gboolean           ephy_file_browse_to           (GFile       *file,
 void               ephy_file_delete_directory    (const char  *path);
 void               ephy_file_delete_uri          (const char  *uri);
 gboolean           ephy_has_private_profile      (void);
+void               ephy_file_load_accels (void);
+void               ephy_file_save_accels (void);
 
 G_END_DECLS
 
