@@ -34,12 +34,11 @@
 #include "ephy-bookmarks-import.h"
 #include "ephy-bookmark-properties.h"
 #include "ephy-prefs.h"
+#include "ephy-settings.h"
 #include "ephy-marshal.h"
 #include "ephy-signal-accumulator.h"
 #include "ephy-stock-icons.h"
 
-#include "eel-gconf-extensions.h"
-
 #include <string.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
@@ -82,7 +81,6 @@ struct _EphyBookmarksPrivate
 	EphyNode *smartbookmarks;
 	EphyNode *lower_fav;
 	double lower_score;
-	guint disable_bookmark_editing_notifier_id;
 
 #ifdef ENABLE_ZEROCONF
 	/* Local sites */
@@ -121,10 +119,7 @@ static char *impl_resolve_address	(EphyBookmarks*, const char*, const char*);
 static void ephy_local_bookmarks_start_client (EphyBookmarks *bookmarks);
 #endif
 
-G_DEFINE_TYPE_WITH_CODE (EphyBookmarks, ephy_bookmarks, G_TYPE_OBJECT,
-			 volatile GType flags_type; /* work around gcc's optimiser */
-			 /* make sure the flags type is known */
-		      	 flags_type = EPHY_TYPE_BOOKMARK_PROPERTY;)
+G_DEFINE_TYPE (EphyBookmarks, ephy_bookmarks, G_TYPE_OBJECT)
 
 static void
 ephy_bookmarks_init_defaults (EphyBookmarks *eb)
@@ -629,14 +624,6 @@ topics_removed_cb (EphyNode *node,
 	}
 }
 
-static void
-update_bookmark_editing (EphyBookmarks *eb)
-{
-	g_object_set (G_OBJECT (eb->priv->db),
-		      "immutable", eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_BOOKMARK_EDITING),
-		      NULL);
-}
-
 static void
 fix_hierarchy_topic (EphyBookmarks *eb,
 		     EphyNode *topic)
@@ -692,15 +679,6 @@ fix_hierarchy (EphyBookmarks *eb)
 	}
 }
 
-static void
-disable_bookmark_editing_notifier (GConfClient *client,
-				   guint cnxn_id,
-				   GConfEntry *entry,
-				   EphyBookmarks *eb)
-{
-	update_bookmark_editing (eb);
-}
-
 static void
 backup_file (const char *original_filename, const char *extension)
 {
@@ -1339,10 +1317,10 @@ ephy_bookmarks_init (EphyBookmarks *eb)
 	
 	fix_hierarchy (eb);
 
-	eb->priv->disable_bookmark_editing_notifier_id = eel_gconf_notification_add
-		(CONF_LOCKDOWN_DISABLE_BOOKMARK_EDITING,
-		 (GConfClientNotifyFunc)disable_bookmark_editing_notifier, eb);
-	update_bookmark_editing (eb);
+	g_settings_bind (EPHY_SETTINGS_LOCKDOWN,
+			 EPHY_PREFS_LOCKDOWN_BOOKMARK_EDITING,
+			 eb->priv->db, "immutable",
+			 G_SETTINGS_BIND_GET);
 
 	ephy_setup_history_notifiers (eb);
 	ephy_bookmarks_update_favorites (eb);
@@ -1354,8 +1332,6 @@ ephy_bookmarks_finalize (GObject *object)
 	EphyBookmarks *eb = EPHY_BOOKMARKS (object);
 	EphyBookmarksPrivate *priv = eb->priv;
 
-	eel_gconf_notification_remove (priv->disable_bookmark_editing_notifier_id);
-
 	if (priv->save_timeout_id != 0)
 	{
 		g_source_remove (priv->save_timeout_id);
@@ -1371,6 +1347,7 @@ ephy_bookmarks_finalize (GObject *object)
 	ephy_node_unref (priv->keywords);
 	ephy_node_unref (priv->favorites);
 	ephy_node_unref (priv->notcategorized);
+	ephy_node_unref (priv->smartbookmarks);
 
 	g_object_unref (priv->db);
 
@@ -1937,30 +1914,55 @@ ephy_bookmarks_unset_keyword (EphyBookmarks *eb,
 	g_signal_emit (G_OBJECT (eb), ephy_bookmarks_signals[TREE_CHANGED], 0);
 }
 
+/**
+ * ephy_bookmarks_get_smart_bookmarks:
+ *
+ * Return value: (transfer none):
+ **/
 EphyNode *
 ephy_bookmarks_get_smart_bookmarks (EphyBookmarks *eb)
 {
 	return eb->priv->smartbookmarks;
 }
 
+/**
+ * ephy_bookmarks_get_keywords:
+ *
+ * Return value: (transfer none):
+ **/
 EphyNode *
 ephy_bookmarks_get_keywords (EphyBookmarks *eb)
 {
 	return eb->priv->keywords;
 }
 
+/**
+ * ephy_bookmarks_get_bookmarks:
+ *
+ * Return value: (transfer none):
+ **/
 EphyNode *
 ephy_bookmarks_get_bookmarks (EphyBookmarks *eb)
 {
 	return eb->priv->bookmarks;
 }
 
+/**
+ * ephy_bookmarks_get_favorites:
+ *
+ * Return value: (transfer none):
+ **/
 EphyNode *
 ephy_bookmarks_get_favorites (EphyBookmarks *eb)
 {
 	return eb->priv->favorites;
 }
 
+/**
+ * ephy_bookmarks_get_local:
+ *
+ * Return value: (transfer none):
+ **/
 EphyNode *
 ephy_bookmarks_get_local (EphyBookmarks *eb)
 {
@@ -1971,12 +1973,22 @@ ephy_bookmarks_get_local (EphyBookmarks *eb)
 #endif
 }
 
+/**
+ * ephy_bookmarks_get_not_categorized:
+ *
+ * Return value: (transfer none):
+ **/
 EphyNode *
 ephy_bookmarks_get_not_categorized (EphyBookmarks *eb)
 {
 	return eb->priv->notcategorized;
 }
 
+/**
+ * ephy_bookmarks_get_from_id:
+ *
+ * Return value: (transfer none):
+ **/
 EphyNode *
 ephy_bookmarks_get_from_id (EphyBookmarks *eb, long id)
 {
