@@ -32,8 +32,9 @@
 #include "ephy-session.h"
 #include "ephy-shell.h"
 #include "ephy-prefs.h"
-#include "ephy-profile-migration.h"
+#include "ephy-profile-utils.h"
 #include "ephy-debug.h"
+#include "ephy-string.h"
 #include "eggsmclient.h"
 
 #include <libxml/xmlversion.h>
@@ -382,43 +383,6 @@ show_error_message (GError **error)
 	gtk_dialog_run (GTK_DIALOG (dialog));
 }
 
-static gchar *
-get_accels_filename (void)
-{
-        const char *home;
-
-        home = g_get_home_dir();
-        if (!home)
-                return NULL;
-        return g_build_filename (home, GNOME_DOT_GNOME, "accels", PACKAGE, NULL);
-}
-
-static void
-load_accels (void)
-{
-        char *filename;
-
-        filename = get_accels_filename ();
-        if (!filename)
-                return;
-
-        gtk_accel_map_load (filename);
-        g_free (filename);
-}
-
-static void
-save_accels (void)
-{
-        char *filename;
-
-        filename = get_accels_filename ();
-        if (!filename)
-                return;
-
-        gtk_accel_map_save (filename);
-        g_free (filename);
-}
-
 static void
 shell_quit_cb (EphyShell *shell, gpointer data)
 {
@@ -578,63 +542,18 @@ main (int argc,
 		exit (1);
 	}
 
-	/* Make URIs from arguments, to support filename args */
-	if (arguments != NULL)
-	{
-		guint i;
-
-		for (i = 0; arguments[i] != NULL; ++i)
-		{
-			char *uri, *path;
-#ifdef PATH_MAX
-			char rpath[PATH_MAX];
-#else
-			char *rpath = NULL;
-#endif
-
-			path = realpath (arguments[i], rpath);
-			if (path != NULL)
-			{
-				uri = g_locale_to_utf8 (path, -1, 
-							NULL, NULL, &error);
-#ifndef PATH_MAX
-				free (path);
-#endif
-			}
-			else
-			{
-				uri = g_locale_to_utf8 (arguments[i], -1, 
-							NULL, NULL, &error);
-			}
-
-			if (uri != NULL)
-			{
-				g_free (arguments[i]);
-
-				/* If it's a file, use g_file_new_for_commandline_arg,
-				 * so we get the right escaping.
-				 */
-				if (path != NULL)
-				{
-					GFile *file;
-					file = g_file_new_for_commandline_arg (uri);
-					arguments[i] = g_file_get_uri (file);
-					g_object_unref (file);
-					g_free (uri);
-				}
-				else
-				{
-					arguments[i] = uri;
-				}
-			}
-			else
-			{
-				g_print ("Could not convert '%s' to UTF-8: %s!\n",
-					 arguments[i], error->message);
-				g_error_free (error);
-				exit (1);
-			}
+	/* convert arguments to uris or at least to utf8 */
+	if (arguments != NULL) {
+		char **args = ephy_string_commandline_args_to_uris (arguments,
+								     &error);
+		if (error) {
+			g_print ("Could not convert to UTF-8: %s!\n",
+				 error->message);
+			g_error_free (error);
+			exit (1);
 		}
+		g_strfreev (arguments);
+		arguments = args;
 	}
 
 	/* Get a timestamp manually if need be */
@@ -714,11 +633,26 @@ main (int argc,
 	}
 
 	/* Migrate profile if we are not running a private instance */
-        if (ephy_has_private_profile () == FALSE)
-          _ephy_profile_migrate ();
+	if (ephy_has_private_profile () == FALSE &&
+	    ephy_profile_utils_get_migration_version () < EPHY_PROFILE_MIGRATION_VERSION)
+	{
+		GError *error = NULL;
+		char *argv[1] = { "ephy-profile-migrator" };
+		char *envp[1] = { "EPHY_LOG_MODULES=ephy-profile" };
+
+		g_spawn_sync (NULL, argv, envp, G_SPAWN_SEARCH_PATH,
+			      NULL, NULL, NULL, NULL,
+			      NULL, &error);
+
+		if (error)
+		{
+			LOG ("Failed to run migrator: %s", error->message);
+			g_error_free (error);
+		}
+	}
 
 	ephy_stock_icons_init ();
-	load_accels ();
+	ephy_file_load_accels ();
 
 	/* Work-around Flash Player crash */
 	g_setenv ("XLIB_SKIP_ARGB_VISUALS", "1", FALSE);
@@ -734,7 +668,7 @@ main (int argc,
 	/* Shutdown */
 	g_object_unref (ephy_shell);
 
-	save_accels ();
+	ephy_file_save_accels ();
 	ephy_state_save ();
 	ephy_settings_shutdown ();
 	ephy_file_helpers_shutdown ();
