@@ -562,7 +562,7 @@ tab_label_style_set_cb (GtkWidget *hbox,
 	context = gtk_widget_get_pango_context (hbox);
 	style = gtk_widget_get_style_context (hbox);
 	metrics = pango_context_get_metrics (context,
-					     gtk_style_context_get_font (style, GTK_STATE_FLAG_ACTIVE),
+					     gtk_style_context_get_font (style, GTK_STATE_FLAG_NORMAL),
 					     pango_context_get_language (context));
 	char_width = pango_font_metrics_get_approximate_digit_width (metrics);
 	pango_font_metrics_unref (metrics);
@@ -586,7 +586,7 @@ build_tab_label (EphyNotebook *nb, EphyEmbed *embed)
 
 	/* set hbox spacing and label padding (see below) so that there's an
 	 * equal amount of space around the label */
-	hbox = gtk_hbox_new (FALSE, 4);
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 4);
 	gtk_widget_show (hbox);
 
 	/* setup load feedback */
@@ -619,9 +619,13 @@ build_tab_label (EphyNotebook *nb, EphyEmbed *embed)
 	provider = gtk_css_provider_new ();
 	gtk_css_provider_load_from_data (provider,
 					 "#ephy-tab-close-button {"
+					 " -GtkButton-default-border: 0;"
+					 " -GtkButton-default-outside-border: 0;"
+					 " -GtkButton-inner-border: 0;"
 					 " -GtkWidget-focus-padding: 0;"
 					 " -GtkWidget-focus-line-width: 0;"
-					 " margin: 0; }",
+					 " margin: 0;"
+					 " padding: 0; }",
 					 -1, NULL);
 
 	gtk_style_context_add_provider (gtk_widget_get_style_context (close_button),
