@@ -167,7 +167,6 @@ confirm_shutdown_dialog_weak_ref_cb (InteractData *data,
 	EphySessionPrivate *priv = data->session->priv;
 	EggSMClient *sm_client = data->sm_client;
 	EphyShell *shell;
-	GObject *dv;
 	gboolean will_quit;
 
 	LOG ("confirm_shutdown_dialog_weak_ref_cb response %d", data->response);
@@ -180,14 +179,6 @@ confirm_shutdown_dialog_weak_ref_cb (InteractData *data,
 		g_object_weak_unref (G_OBJECT (shell),
 				     (GWeakNotify) confirm_shutdown_dialog_accept_cb,
 				     data);
-
-		dv = ephy_embed_shell_get_downloader_view_nocreate (ephy_embed_shell_get_default ());
-		if (dv != NULL)
-		{
-			g_object_weak_unref (dv,
-					     (GWeakNotify) confirm_shutdown_dialog_accept_cb,
-					     data);
-		}
 	}
 
 	if (data->timeout_id != 0)
@@ -208,15 +199,16 @@ client_quit_requested_cb (EggSMClient *sm_client,
 			  EphySession *session)
 {
 	EphySessionPrivate *priv = session->priv;
-	GObject *dv;
 	GtkWidget *dialog, *box;
 	InteractData *data;
+	GList *downloads;
 
 	/* If we're shutting down, check if there are downloads
 	 * remaining, since they can't be restarted.
 	 */
-	if (ephy_shell_get_default () == NULL ||
-	    (dv = ephy_embed_shell_get_downloader_view_nocreate (ephy_embed_shell_get_default ())) == NULL)
+
+	downloads = ephy_embed_shell_get_downloads (embed_shell);
+	if (ephy_shell_get_default () == NULL || g_list_length (downloads) == 0)
 	{
 		egg_sm_client_will_quit (sm_client, TRUE);
 		return;
@@ -271,11 +263,6 @@ client_quit_requested_cb (EggSMClient *sm_client,
 			   (GWeakNotify) confirm_shutdown_dialog_accept_cb,
 			   data);
 
-	/* When the download finishes, un-veto the shutdown */
-	g_object_weak_ref (dv,
-			   (GWeakNotify) confirm_shutdown_dialog_accept_cb,
-			   data);
-
 	g_signal_connect (dialog, "response",
 			  G_CALLBACK (confirm_shutdown_dialog_response_cb), data);
 	g_object_weak_ref (G_OBJECT (dialog),
@@ -557,7 +544,7 @@ session_command_autoresume (EphySession *session,
 
 	ephy_session_queue_command (session,
 				    EPHY_SESSION_CMD_MAYBE_OPEN_WINDOW_RESTORE,
-				    NULL, NULL, user_time, FALSE);
+				    NULL, NULL, user_time, TRUE);
 }
 
 static void
@@ -625,14 +612,29 @@ session_command_open_uris (EphySession *session,
 
 		/* For the first URI, if we have a valid recovery
 		 * window, reuse the already existing embed instead of
-		 * creating a new one */
+		 * creating a new one, except if we still want to
+		 * present the option to resume a crashed session, in
+		 * that case use a new tab in the same window */
 		if (i == 0 && priv->resume_window != NULL)
 		{
-			EphyWebView *web_view;
-			
-			embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (priv->resume_window));
-			web_view = ephy_embed_get_web_view (embed);
-			ephy_web_view_load_url (web_view, url);
+			if (priv->resume_infobar != NULL)
+			{
+				embed = ephy_shell_new_tab_full (shell, EPHY_WINDOW (priv->resume_window),
+								 NULL /* parent tab */,
+								 request,
+								 EPHY_NEW_TAB_IN_EXISTING_WINDOW | page_flags,
+								 EPHY_WEB_VIEW_CHROME_ALL,
+								 FALSE /* is popup? */,
+								 user_time);
+			}
+			else
+			{
+				EphyWebView *web_view;
+
+				embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (priv->resume_window));
+				web_view = ephy_embed_get_web_view (embed);
+				ephy_web_view_load_url (web_view, url);
+			}
 		}
 		else
 		{
@@ -766,7 +768,7 @@ session_command_dispatch (EphySession *session)
 				session->priv->resume_window = gtk_widget_get_toplevel (GTK_WIDGET (embed));
 
 				action_area = gtk_info_bar_get_action_area (GTK_INFO_BAR (info_bar));
-				button_box = gtk_hbutton_box_new ();
+				button_box = gtk_button_box_new (GTK_ORIENTATION_HORIZONTAL);
 				gtk_container_add (GTK_CONTAINER (action_area), button_box);
 
 				action_button = gtk_button_new_with_label (_("Don't recover"));
@@ -808,8 +810,7 @@ session_command_dispatch (EphySession *session)
 	}
 
 	/* Look if there's anything else to dispatch */
-	if (g_queue_is_empty (priv->queue) ||
-	    priv->resume_window != NULL)
+	if (g_queue_is_empty (priv->queue))
 	{
 		priv->queue_idle_id = 0;
 		run_again = FALSE;
@@ -1633,6 +1634,7 @@ ephy_session_load (EphySession *session,
 	xmlFreeDoc (doc);
 
 	priv->dont_save = FALSE;
+	priv->resume_window = NULL;
 
 	ephy_session_save (session, SESSION_CRASHED);
 
